@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.36 2002/05/26 19:00:54 kevinv Exp $ */
+/* $Id: gdict-applet.c,v 1.41 2003/05/18 17:15:52 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -66,8 +66,8 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
         	return;
         
     	g_strdown (text);
+	gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
     	gdict_app_do_lookup (text);
-    	gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     	g_free (text);
  
 
@@ -90,6 +90,30 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
 	
 }
 
+static void 
+menu_event_cb (BonoboUIComponent            *comp,
+               const gchar                  *path,
+               Bonobo_UIComponent_EventType  type,
+               const gchar                  *state_string,
+               gpointer                     *data)
+{
+	if (!context) {
+		gdict_init_context ();
+	}
+		
+	if (strcmp (path, "def win") == 0) {
+		
+		if (strcmp (state_string, "1") == 0) {
+			if (!GTK_WIDGET_VISIBLE (gdict_app)) { 
+        			gtk_widget_show (gdict_app);
+			}
+		}
+		else if (GTK_WIDGET_VISIBLE (gdict_app)) { 
+			gtk_widget_hide (gdict_app);
+		}
+	}
+}
+
 static void
 text_received (GtkClipboard *clipboard, const gchar *text, gpointer data)
 {
@@ -132,10 +156,24 @@ static gboolean
 button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
     GtkWidget *applet = GTK_WIDGET (data);
+    BonoboUIComponent *component;
+	
+    if (event->button == 3) { 
+    
+	if (!context) {
+		gdict_init_context ();
+	}
+	
+	component = panel_applet_get_popup_component ((PanelApplet *)applet);
+	bonobo_ui_component_set_prop (component,
+				      "/commands/def win",
+				      "state",
+				      GTK_WIDGET_VISIBLE (gdict_app) ? "1" : "0",
+				      NULL); 
+    }
     
     if (event->button == 3 || event->button == 2) {
-	event->window = applet->window;
-	gtk_main_do_event ((GdkEvent *) event);
+	gtk_propagate_event (applet, (GdkEvent *) event);
 
 	return TRUE;
     }
@@ -159,7 +197,7 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-	gdict_about();
+	gdict_about(NULL);
 }
 
 static void
@@ -168,7 +206,27 @@ help_cb (BonoboUIComponent *uic,
           const gchar       *verbname)
 {
 	GError *error = NULL;
-        gnome_help_display("gnome-dictionary",NULL,&error);
+	gnome_help_display("gnome-dictionary",NULL,&error);
+
+	if (error)
+	{
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 ("There was an error displaying help: \n%s"),
+						 error->message);
+
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -181,19 +239,6 @@ prefs_cb (BonoboUIComponent *uic,
 	gdict_app_show_preferences ();
 }
 
-static void
-show_hide_defbox_cb (BonoboUIComponent *uic,
-          gpointer           user_data,
-          const gchar       *verbname)
-{
-	if (!context)
-		gdict_init_context ();
-	if (!GTK_WIDGET_VISIBLE (gdict_app)) 
-        	gtk_widget_show (gdict_app);
-    	else
-        	gtk_widget_hide (gdict_app);
-}
-
 static void
 spell_cb (BonoboUIComponent *uic,
           gpointer           user_data,
@@ -212,7 +257,6 @@ spell_cb (BonoboUIComponent *uic,
 }
 
 static const BonoboUIVerb gdict_applet_menu_verbs [] = {
-	BONOBO_UI_VERB ("def win", show_hide_defbox_cb),
 	BONOBO_UI_VERB ("sel", lookup_selected_text),
         BONOBO_UI_VERB ("prefs", prefs_cb),
         BONOBO_UI_VERB ("help", help_cb),
@@ -225,6 +269,7 @@ static gboolean
 gdict_applet_new (PanelApplet *parent_applet)
 {
 	GDictApplet *applet;
+	BonoboUIComponent *component;
  	GtkWidget *hbox;
 
  	static GtkTargetEntry drop_targets [] = {
@@ -276,6 +321,9 @@ gdict_applet_new (PanelApplet *parent_applet)
  	/* server will be contacted when an action is performed */
  	context = NULL;
 	
+	component = panel_applet_get_popup_component ((PanelApplet *)applet->applet_widget);
+	g_signal_connect (component, "ui-event", (GCallback) menu_event_cb, NULL);
+	
  	g_signal_connect (G_OBJECT (applet->entry_widget), "activate",
  			  G_CALLBACK (entry_activate_cb), applet);
 
