@@ -173,6 +173,7 @@ init_devices (void)
 							 GTK_BUTTONS_CLOSE,
 							 msg);
 			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 			exit (1);
 		}
 		/* Device is okay */
@@ -213,6 +214,7 @@ init_devices (void)
 							 GTK_BUTTONS_CLOSE,
 							 msg);
 			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 			exit (1);
 		} else if (ok_devices_present == 1) {
 			for (i = 0; i < NUM_DEVICES_TO_CHECK; i++) {
@@ -406,21 +408,35 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 	GtkWidget *dialog;
 	GtkWidget *type_option;
 	GtkWidget *density_option;
-	GtkWidget *quick_format_rb;
+	GtkWidget *volume_name_entry;
 
         type_option = glade_xml_get_widget (xml, "type_option");
         density_option = glade_xml_get_widget (xml, "density_option");
+	volume_name_entry = glade_xml_get_widget (xml, "volume_name_entry");
 
-        gtk_widget_set_sensitive (toplevel, FALSE);
+	floppy.volume_name = (gchar *) gtk_entry_get_text (GTK_ENTRY (volume_name_entry));
 
-        if (floppy.mformat_cmd) {
-        	/* Check to see which one is selected. */
-                floppy.type = gtk_option_menu_get_history (GTK_OPTION_MENU (type_option));
-        } else {
-                floppy.type = GFLOPPY_E2FS;
-        }
+	if (strstr (floppy.volume_name, " ")) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("The volume name can't contain any blank space."));
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		return;
+	}
+
+	gtk_widget_set_sensitive (toplevel, FALSE);
+
+	/* If we can format in either types */
+	if (floppy.mke2fs_cmd && (floppy.mkdosfs_cmd || floppy.mformat_cmd))
+		floppy.type = gtk_option_menu_get_history (GTK_OPTION_MENU (type_option)); /* user choice */
+	else
+		floppy.type = floppy.mke2fs_cmd ? GFLOPPY_E2FS : GFLOPPY_FAT; /* otherwise just use the available one */
 
-	floppy.type = gtk_option_menu_get_history (GTK_OPTION_MENU (type_option));
 	floppy.size = gtk_option_menu_get_history (GTK_OPTION_MENU (density_option));
 	floppy.formatting_mode = get_selected_formatting_mode ();
 
@@ -428,35 +444,25 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 
         start_format ();
 
-        if (!toplevel)
-        	return;
-
-        gtk_widget_set_sensitive (toplevel, TRUE); /*
-        dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-                                         GTK_DIALOG_MODAL,
-                                         GTK_MESSAGE_QUESTION,
-                                         GTK_BUTTONS_YES_NO,
-                                         _("Format another floppy?"));
-        if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES)
-        	exit (0);
-        gtk_widget_destroy (dialog); */
+        gtk_widget_set_sensitive (toplevel, TRUE);
 }
 
 int
 main (int argc, char *argv[])
 {
+	const GnomeIconData *icon_data;
+	gchar *icon_path = NULL;
 	GConfClient *client;
 	GFloppyConfig config;
+        GnomeIconTheme *icon_theme;
 	GtkWidget *fs_entry;
 	GtkWidget *type_option;
-	GtkWidget *volume_name_cb;
-	GtkWidget *volume_name_entry;
 	GtkWidget *quick_format_rb;
 	GtkWidget *default_mode_rb;
 	GtkWidget *device_combo;
 	GSList *l;
-	gchar *image;
 	gint i;
+        gint base_size;
 
 	struct poptOption gfloppy_opts[] = {
 		{"device", '\0', POPT_ARG_STRING, NULL, 0, NULL, NULL},
@@ -476,11 +482,14 @@ main (int argc, char *argv[])
 			    argc, argv, GNOME_PARAM_POPT_TABLE, gfloppy_opts,
                             GNOME_PARAM_POPT_FLAGS, 0,
                             GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
-	/* FIXME: get the right icon */
-	image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-                                           "document-icons/i-floppy.png", TRUE, NULL);
-	gnome_window_icon_set_default_from_file (image);
-	g_free (image);
+
+        icon_theme = gnome_icon_theme_new ();
+        icon_path = gnome_icon_theme_lookup_icon (icon_theme, "gnome-dev-floppy", 24.0,
+                                                              &icon_data, &base_size);
+
+        if (icon_path)
+	  gnome_window_icon_set_default_from_file (icon_path);
+	g_free (icon_path);
 
 	init_commands ();
 
@@ -497,8 +506,6 @@ main (int argc, char *argv[])
 	
 	toplevel = glade_xml_get_widget (xml, "toplevel");
 	type_option = glade_xml_get_widget (xml, "type_option");
-	volume_name_cb = glade_xml_get_widget (xml, "volume_name_cb");
-	volume_name_entry = glade_xml_get_widget (xml, "volume_name_entry");
         quick_format_rb = glade_xml_get_widget (xml, "quick_format_rb");
 
 	/* Signals connection */
@@ -507,9 +514,6 @@ main (int argc, char *argv[])
 
 	g_signal_connect (type_option, "changed",
 			  G_CALLBACK (type_option_changed_cb), NULL);
-	g_signal_connect (volume_name_cb, "toggled",
-			  G_CALLBACK (set_widget_sensitive_from),
-			  volume_name_entry);
 
 	/* GConf support */
 	client = gconf_client_get_default ();
@@ -532,7 +536,7 @@ main (int argc, char *argv[])
 	/* Sync UI from config. We don't emit any signal here, since we emit
 	   just after this sync the "changed" signal of type_option,
 	   which emit all the other necessary signals */
-	if (!strcmp (config.default_fs, GFLOPPY_CONFIG_FS_FAT))
+	if (config.default_fs && !strcmp (config.default_fs, GFLOPPY_CONFIG_FS_FAT))
 		gtk_option_menu_set_history (GTK_OPTION_MENU (type_option), GFLOPPY_FAT);
 	else
 		gtk_option_menu_set_history (GTK_OPTION_MENU (type_option), GFLOPPY_E2FS);
