@@ -117,6 +117,10 @@ click_find_cb (GtkWidget	*widget,
 {
 	gchar *command;
 
+	if (search_command.not_running_timeout == TRUE) {
+		return;
+	}
+
 	gtk_widget_set_sensitive (interface.stop_button, FALSE);
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 
@@ -126,10 +130,8 @@ click_find_cb (GtkWidget	*widget,
 		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
 		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), 
 				   _("Searching..."));
-		search_command.timeout = gtk_timeout_add (100, update_progress_bar, 
-							  NULL); 
-		search_command.show_hidden_files = FALSE;
-		
+		search_command.timeout = g_timeout_add (100, update_progress_bar, 
+						  	NULL); 
 		spawn_search_command (command);
 	}
 	
@@ -175,7 +177,7 @@ add_constraint_cb (GtkWidget 	*widget,
 	item = gtk_menu_get_active (GTK_MENU(menu));
 	
 	if (GTK_WIDGET_SENSITIVE(item) == TRUE) {
-		add_constraint (interface.selected_constraint, NULL);
+		add_constraint (interface.selected_constraint, NULL, FALSE);
 	}
 }
 
@@ -185,7 +187,7 @@ remove_constraint_cb (GtkWidget 	*widget,
 {
 	SearchConstraint *constraint = data;
 	
-      	interface.geometry.min_height -= 30;
+      	interface.geometry.min_height -= 35;
 	
 	gtk_window_set_geometry_hints (GTK_WINDOW(interface.main_window), 
 				       GTK_WIDGET(interface.main_window),
@@ -197,6 +199,7 @@ remove_constraint_cb (GtkWidget 	*widget,
 		g_list_remove(interface.selected_constraints, constraint);
 	
 	set_constraint_selected_state (constraint->constraint_id, FALSE);	
+	set_constraint_gconf_boolean (constraint->constraint_id, FALSE);	
 }
 
 void
@@ -232,7 +235,6 @@ void
 constraint_entry_changed_cb (GtkWidget 	*widget, 
 			     gpointer 	data)
 {
-	static gchar *file_is_named_string;
 	static gchar *look_in_folder_string;
 	
 	if (GTK_WIDGET_VISIBLE (interface.main_window) == FALSE) {
@@ -475,6 +477,18 @@ file_button_press_event_cb (GtkWidget 		*widget,
 	return !(row_selected_by_button_press_event);
 }
 
+gboolean
+file_key_press_event_cb  (GtkWidget 		*widget, 
+		    	  GdkEventKey	 	*event, 
+		     	  gpointer 		data)
+{		
+	if (event->keyval == GDK_space || event->keyval == GDK_Return) {
+		open_file_cb (widget, data);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 gboolean
 file_button_release_event_cb (GtkWidget 	*widget, 
 		      	      GdkEventButton 	*event, 
@@ -851,11 +865,12 @@ save_session_cb (GnomeClient 	    *client,
 		 gint 		    fast,
  	      	 gpointer 	    client_data)
 {
- 	gchar *argv[] = { NULL };
- 
- 	argv[0] = (gchar *) client_data;
- 	gnome_client_set_clone_command (client, 1, argv);
- 	gnome_client_set_restart_command (client, 1, argv);	
+	char **argv;
+	int argc;
+
+	set_clone_command (&argc, &argv, client_data);
+	gnome_client_set_clone_command (client, argc, argv);
+	gnome_client_set_restart_command (client, argc, argv);	
 }
 
 gboolean
@@ -869,7 +884,7 @@ key_press_cb (GtkWidget    	*widget,
 		if (search_command.running == RUNNING) {
 			click_stop_cb (widget, NULL);
 		}
-		else {
+		else if (search_command.not_running_timeout == FALSE) {
 			quit_cb (widget, NULL);
 		}
 	}
@@ -921,3 +936,10 @@ look_in_folder_key_press_cb (GtkWidget    	*widget,
 	}
 	return FALSE;
 }
+
+gboolean
+not_running_timeout_cb (gpointer data)
+{
+	search_command.not_running_timeout = FALSE;
+	return FALSE;
+}
